package
Version:
v0.0.25
Opens a new window with list of versions in this module.
Published: Jan 8, 2023
License: CC0-1.0
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func (t *Table[K, V]) Delete(key K)
func (t *Table[K, V]) Insert(key K, value V)
func (t *Table[K, V]) Lookup(key K) (value V, ok bool)
Source Files
¶
Click to show internal directories.
Click to hide internal directories.